def tssplit(s, quote='"', delimiter='/', escape='|'):
    """Split a string by delimiters with escaped characters and quotes

    :param s: A string to split into chunks
    :param quote: Quote signs to protect a part of s fro parsing
    :param delimiter: A chunk separator symbol
    :param escape: An escape character
    :return: A list of chunks
    """

    in_quotes = in_escape = False
    token = ''
    result = []

    for c in s:
        if in_escape:
            token += c
            in_escape = False
        elif c == escape:
            in_escape = True
            if in_quotes:
                token += c
        elif c == quote and not in_escape:
            in_quotes = False if in_quotes else True
        elif c == delimiter and not in_quotes:
            result.append(token)
            token = ''
        else:
            token += c

    result.append(token)
    return result


if __name__ == "__main__":
    pass



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='tssplit',
    version='1.0.2',
    py_modules=['tssplit.tssplit'],
    url='https://github.com/mezantrop/tssplit',
    license='bsd-2-clause',
    author='Mikhail Zakharov',
    author_email='zmey20000@yahoo.com',
    description='Trivial split for strings with escaped characters and quotes',
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        'License :: OSI Approved :: BSD License',
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development',
        'Topic :: Text Processing',
        'Topic :: Text Processing :: Filters',
        'Topic :: Text Processing :: General'
    ],
    keywords=['split', 'parse', 'quote'],

)
